==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-locale/lxqt-config-locale.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="38"/>
        <source>LXQt Locale Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="43"/>
        <source>Locale Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-locale/lxqt-config-locale.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
